@@ -1,7 +1,7 @@
-/* Definition of class NSOrthography
+/**Definition of class NSOrthography
    Copyright (C) 2019 Free Software Foundation, Inc.
    
-   By: heron
+   By: Gregory Casamento <greg.casamento@gmail.com>
    Date: Tue Nov  5 03:43:39 EST 2019
 
    This file is part of the GNUstep Library.
