@@ -54,6 +54,7 @@ extern "C" {
  * without threading.  Non-threaded applications are more efficient
  * (no locking is required) and are easier to debug during development.
  */
+GS_EXPORT_CLASS
 @interface NSThread : NSObject
 {
 #if	GS_EXPOSE(NSThread)
@@ -133,7 +134,7 @@ extern "C" {
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_2,GS_API_LATEST) \
   && GS_API_VERSION( 10200,GS_API_LATEST)
-+ (void) setThreadPriority: (double)pri;
++ (BOOL) setThreadPriority: (double)pri;
 + (double) threadPriority;
 #endif
 
